@@ -1484,17 +1484,17 @@ class ImmutableField(Field):
     _immutable = True
 
 
-class ABCStructure(Structure):
+class AbstractStructure(Structure):
     """
-    A replacement to extending (Structure, ABC). In other words, Defines a Structure class
-    That cannot be instantiated because it is abstract. To instantiate, you are required to extend it.
+    Defines a Structure class that cannot be instantiated because it is abstract.
+     To instantiate, you are required to extend it.
     """
     def __init__(self, *args, **kwargs):
-        found_subclass = False
-        for clz in self.__class__.__mro__[1:]:
-            if issubclass(clz, ABCStructure) and not clz is ABCStructure:
-                found_subclass = True
+        found = False
+        for clz in self.__class__.__bases__:
+            if clz is AbstractStructure:
+                found = True
                 break
-        if not found_subclass:
+        if found:
             raise TypeError("Not allowed to instantiate an abstract Structure")
         super().__init__(*args, **kwargs)
